@@ -16,5 +16,6 @@
 
 "The lazr.smtptest package."
 
-
-__version__ = '1.2'
+import pkg_resources
+__version__ = pkg_resources.resource_string(
+    "lazr.smtptest", "version.txt").strip()
